<?php
/**
Allows viewing of contest entries.
 **/
require_once 'util.php';
require_once 'form.php';
require_once 'contsettings.php';
require_once 'contdata.php';

// Get secret and check
$secret = req('secret');
if ($secret != CONTEST_SECRET) die('Not allowed');

// Get action
$action = req('action');
if ($action == ACT_DOWNLOAD) {
    ContData::export();
    exit;
}

// Get page
$pg = intval(req('pg', 1));

// Get appropriate directory
$dir = array_key_exists($action, $actdir) ? $actdir[$action] : req('dir', DIR_QUEUE);
$msg = '';

//  Get filename and load details
$fn = req('fn');
if ($fn) {
    $cont = new ContData($dir);
    $found = $cont->loadFromFile($fn);
    if (!$found) {
        $msg = '<p>File could not be found.</p>';
    }
} else {
    $found = false;
}

if ($found) {
    switch ($action) {
        // If Accept then update data and move to accepted entries.
        case ACT_ACCEPT:
            $cont->post();
            $cont->moveTo(DIR_ENTRY);
            $msg = '<p>Picture has been accepted.</p>';
            break;

        // If Requeue then move back to queue.
        case ACT_REQUEUE:
            $cont->post();
            $cont->moveTo(DIR_QUEUE);
            $msg = '<p>Picture has been put back in queue.</p>';
            break;

        // If Delete then move to trash.
        case ACT_DELETE:
            $cont->post();
            $cont->moveTo(DIR_TRASH);
            $msg = '<p>Picture has been deleted.</p>';
            break;

        // If Save then save (leave in current directory).
        case ACT_SAVE:
            $cont->post();
            $msg = '<p>Details saved.</p>';
            break;

        default:
            break;
    }
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en"
      xmlns:fb="http://www.facebook.com/2008/fbml">
<head>
    <title>Coloring Contest Entries</title>
    <link rel="stylesheet" type="text/css" href="contest.css"/>
    <link rel="stylesheet" type="text/css" href="form.css"/>
</head>
<body>
<div id="main">
<?php
// Action - Accepted or Deleted or List.
    if ($action || !$found) {
        echo $msg;
        echo '<h1>' . $dirtitle[$dir] . '</h1>';

        switch ($dir) {
            case DIR_TRASH:
                $btns = array(ACT_ENTRIES, ACT_QUEUE, ACT_DOWNLOAD);
//                $sort = FN_DATE;
                $sort = FN_AGE;
                break;

            case DIR_QUEUE:
                $btns = array(ACT_ENTRIES, ACT_TRASH, ACT_DOWNLOAD);
//                $sort = FN_DATE;
                $sort = FN_AGE;
                break;

            case DIR_ENTRY:
            default:
                $btns = array(ACT_QUEUE, ACT_TRASH, ACT_DOWNLOAD);
                $sort = FN_AGE;
                break;
        }

        $n = ContData::showList($dir, $sort, $pg);

        echo '<div id="listopts">';
        formBegin('contform', 'contview.php');
        if ($n == 0) {
            formMsg('Choose a list to view.');
        } else {
            $msgpg = $n > PAGE_SIZE ? 'choose a different page, ' : '';
            formMsg('Click one of the above entries to edit, ' . $msgpg . 'or choose a list to view.');
            if ($n > PAGE_SIZE) {
                formPgButtons(ceil($n / PAGE_SIZE), $pg);
            }
        }
        formButtons($btns);
        // Also, pass on extra variables to next script
        formHidden('secret', $secret);
        formHidden('dir', $dir);
        formEnd();
        echo '</div>';
        // End: Action
    } else {
        // No Action - Show form for editing and Accept / Delete.
        include($dir . '.html');
        ?>
        <div id="full"><img src="<?php echo $cont->imgfile(); ?>" width="<?php echo $cont->imgw;?>"
                            height="<?php echo $cont->imgh;?>"></div>
        <div id="fullinfo">
            <?php
            formBegin('contform', 'contview.php');
            formRow(FN_PERSON, FLD_PERSON, $cont->person, FT_TEXT_MEDIUM);
            formRow(FN_EMAIL, FLD_EMAIL, $cont->email, FT_TEXT_LARGE);
            formRow(FN_IP, FLD_IP, $cont->ip, FT_TEXT_MEDIUM);
            formRow(FN_AGE, FLD_AGE, $cont->age, FT_NUMBER);
            formRow(FN_LOC, FLD_LOC, $cont->loc, FT_TEXT_MEDIUM);
            formRow(FN_DESC, FLD_DESC, $cont->desc, FT_TEXT_AREA);
            switch ($dir) {
                case DIR_TRASH:
                    $btns = array(ACT_SAVE, ACT_ACCEPT, ACT_REQUEUE);
                    break;

                case DIR_QUEUE:
                    $btns = array(ACT_SAVE, ACT_ACCEPT, ACT_DELETE);
                    break;

                case DIR_ENTRY:
                default:
                    $btns = array(ACT_SAVE, ACT_REQUEUE, ACT_DELETE);
                    break;
            }
            formButtons($btns);
            formButtons(array(ACT_ENTRIES, ACT_QUEUE, ACT_TRASH));
            // Also, pass on extra variables to next script
            formHidden('dir', $dir);
            formHidden('fn', $fn);
            formHidden('secret', $secret);
            formEnd();
            ?>
        </div>
        <?php

        // End: No Action
    }
    ?>
</div>
</body>
</html>
